Contrast Sensitivity
====================

Contrast Sensitivity
--------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    contrast_sensitivity_function
    CONTRAST_SENSITIVITY_METHODS

Barten (1999) Contrast Sensitivity Function
-------------------------------------------

``colour.contrast``

.. currentmodule:: colour.contrast

.. autosummary::
    :toctree: generated/

    contrast_sensitivity_function_Barten1999

**Ancillary Objects**

``colour.contrast``

.. currentmodule:: colour.contrast

.. autosummary::
    :toctree: generated/

    optical_MTF_Barten1999
    pupil_diameter_Barten1999
    sigma_Barten1999
    retinal_illuminance_Barten1999
    maximum_angular_size_Barten1999
